pub struct NominalIssue {
pub identity: ProductIdentity,
pub due_at: ProductDateTime,
pub covers: NominalCoverage,
}Expand description
The next catalog issue nominally due at or after a query instant.
Fields
identity: ProductIdentityExact product identity expected at the due time.
due_at: ProductDateTimeNominal publication deadline in UTC.
covers: NominalCoverageNominal observed and predicted coverage named by the identity.