pub enum WindowContinuityDecision {
Accept,
Refuse,
}Expand description
Window-scoped continuity decision.
Variants
Accept
No recorded finding can enter an interpolation stencil for the window.
Refuse
At least one recorded finding can enter an interpolation stencil.