ukf_correct_closed_loop

Function ukf_correct_closed_loop 

pub fn ukf_correct_closed_loop(
    state: &mut InsFilterState,
    correction: &EkfCorrection,
    options: UkfUpdateOptions,
) -> Result<EkfCorrectionReport, FusionError>
Apply a linear UKF correction, then close the loop and reset the error vector.

This uses the same EkfCorrection measurement struct as the EKF path. The supplied design matrix is evaluated as a linear measurement function at each sigma point.