pub struct SatelliteObservationQc {
pub satellite: GnssSatelliteId,
pub epochs_with_observations: usize,
pub value_observations: usize,
}Expand description
Per-satellite observation counts.
Fields
satellite: GnssSatelliteIdSatellite id.
epochs_with_observations: usizeEpochs where the satellite has at least one non-blank observation value.
value_observations: usizeNon-blank observation values across all codes and observation epochs.