pub struct AirborneModel {
pub sigma_noise_divergence_m: f64,
}Expand description
Airborne receiver and multipath contribution model.
Fields
sigma_noise_divergence_m: f64Receiver noise and code-carrier divergence sigma, meters.
Implementations
Sourceimpl AirborneModel
impl AirborneModel
Sourcepub const fn new(sigma_noise_divergence_m: f64) -> AirborneModel
pub const fn new(sigma_noise_divergence_m: f64) -> AirborneModel
Construct an airborne model from a supplied receiver noise term.
Sourcepub const fn aad_a() -> AirborneModel
pub const fn aad_a() -> AirborneModel
DO-229 AAD-A airborne model.
Sourcepub fn sigma_air_m(self, elevation_rad: f64) -> Option<f64>
pub fn sigma_air_m(self, elevation_rad: f64) -> Option<f64>
Airborne receiver, divergence, and multipath sigma at an elevation.