pub struct ImuCalibration {
pub accel_scale_misalignment: [[f64; 3]; 3],
pub gyro_scale_misalignment: [[f64; 3]; 3],
}Expand description
IMU scale-factor and misalignment matrices.
Each matrix is the M in (I + M)^-1(measured - bias).
Fields
accel_scale_misalignment: [[f64; 3]; 3]Accelerometer scale and misalignment matrix.
gyro_scale_misalignment: [[f64; 3]; 3]Gyroscope scale and misalignment matrix.
Implementations
Sourceimpl ImuCalibration
impl ImuCalibration
Sourcepub fn from_scale_ppm(
accel_scale_ppm: [f64; 3],
gyro_scale_ppm: [f64; 3],
) -> Result<ImuCalibration, InertialError>
pub fn from_scale_ppm( accel_scale_ppm: [f64; 3], gyro_scale_ppm: [f64; 3], ) -> Result<ImuCalibration, InertialError>
Build a diagonal calibration from scale factors in parts per million.
Sourcepub fn validate(&self) -> Result<(), InertialError>
pub fn validate(&self) -> Result<(), InertialError>
Validate finite calibration matrices and invertibility of I + M.