pub struct SerializableTightGnssEpoch {
pub t_j2000_s: F64Bits,
pub observations: Vec<SerializableTightGnssObservation>,
}Expand description
Serializable tight raw GNSS epoch.
Fields
t_j2000_s: F64BitsMeasurement epoch in seconds since J2000, stored as raw f64 bits.
observations: Vec<SerializableTightGnssObservation>Satellite observations at the epoch.
Implementations
Sourceimpl SerializableTightGnssEpoch
impl SerializableTightGnssEpoch
Sourcepub fn from_native(epoch: &TightGnssEpoch) -> SerializableTightGnssEpoch
pub fn from_native(epoch: &TightGnssEpoch) -> SerializableTightGnssEpoch
Convert a native tight epoch into the serialized form.
Sourcepub fn to_native(&self) -> Result<TightGnssEpoch, FusionStateCodecError>
pub fn to_native(&self) -> Result<TightGnssEpoch, FusionStateCodecError>
Convert the serialized tight epoch back to native values.